# remirepo/fedora spec file for php-zephir-parser
#
# Copyright (c) 2016-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%if 0%{?scl:1}
%scl_package php-zephyr-parser
%endif

%global with_tests   0%{!?_without_tests:1}
%global gh_commit    3cdd0eb17e2e2cbc57ff64c284a23b904e26289b
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
#global gh_date      20161126
%global gh_owner     phalcon
%global gh_project   php-zephir-parser
%global ext_name     zephir_parser

Name:           %{?scl_prefix}%{gh_project}
Version:        1.3.4
Release:        1%{?gh_date:.%{gh_date}git%{gh_short}}%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
Summary:        Zephir parser extension

License:        MIT
URL:            https://getcomposer.org/
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{gh_short}.tar.gz

BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel > 7
%if 0%{?rhel} == 6
BuildRequires:  re2c014
%else
BuildRequires:  re2c >= 0.13.6
%endif

Requires:     %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:     %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Obsoletes:    %{?scl_prefix}zephir-parser < 0.10
Provides:     %{?scl_prefix}zephir-parser = %{version}


%description
The Zephir Parser delivered as a C extension for the PHP language.


%package devel
Summary:       %{name} developer files (headers)
Requires:      %{name}%{?_isa} = %{version}-%{release}
Requires:      %{?scl_prefix}php-devel%{?_isa}

%description devel
These are the files needed to compile programs using %{name}.


%prep
%setup -q -n %{gh_project}-%{gh_commit}

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_ZEPHIR_PARSER_VERSION/{s/.* "//;s/".*$//;p}' zephir_parser.h)
if test "x${extver}" != "x%{version}%{?gh_date:-dev}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?gh_date:-dev}.
   exit 1
fi


%build
%{?dtsenable}

%{_bindir}/phpize
%configure \
    --with-php-config=%{_bindir}/php-config \
    --enable-zephir_parser

make %{?_smp_mflags}


%install
%{?dtsenable}
make install INSTALL_ROOT=%{buildroot}


%check
: Check extension
%{_bindir}/php -n -d extension=modules/%{ext_name}.so -m | grep "Zephir Parser"

%if %{with_tests}
: Run test suite
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{ext_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc CREDITS NO_WARRANTY
%doc *.md
%{php_extdir}/%{ext_name}.so


%files devel
%{php_incldir}/ext/%{ext_name}



%changelog
* Mon Apr  6 2020 Remi Collet <remi@remirepo.net> - 1.3.4-1
- update to 1.3.4

* Wed Dec 11 2019 Remi Collet <remi@remirepo.net> - 1.3.3-1
- update to 1.3.3

* Tue Oct  1 2019 Remi Collet <remi@remirepo.net> - 1.3.2-1
- update to 1.3.2

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.3.1-2
- rebuild for 7.4.0RC1

* Thu May  2 2019 Remi Collet <remi@remirepo.net> - 1.3.1-1
- update to 1.3.1

* Mon Apr 29 2019 Remi Collet <remi@remirepo.net> - 1.3.0-1
- update to 1.3.0

* Mon Jan 14 2019 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0
- raise minimal PHP version to 7

* Thu Nov 22 2018 Remi Collet <remi@remirepo.net> - 1.1.4-1
- update to 1.1.4

* Tue Nov  6 2018 Remi Collet <remi@remirepo.net> - 1.1.3-1
- update to 1.1.3
- add devel sub-package
- adopt standard php build system (phpize)

* Mon Feb 26 2018 Remi Collet <remi@remirepo.net> - 1.1.2-2
- use "module load ..." command instead of "scl enable ..."

* Tue Jan 23 2018 Remi Collet <remi@remirepo.net> - 1.1.2-1
- update to 1.1.2

* Fri Nov 10 2017 Remi Collet <remi@remirepo.net> - 1.1.1-1
- update to 1.1.1

* Thu Oct 12 2017 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0

* Wed Oct 11 2017 Remi Collet <remi@remirepo.net> - 1.0.3-1
- rename from zephir-parser to php-zephir-parser
- update to 1.0.3 (for zephir 0.10)

* Fri Aug  4 2017 Remi Collet <remi@remirepo.net> - 0.9.11-1
- version 0.9.11

* Tue Aug  1 2017 Remi Collet <remi@remirepo.net> - 0.9.10-1
- version 0.9.10

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.9.9-2
- rebuild for PHP 7.2.0beta1 new API

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 0.9.9-1
- version 0.9.9

* Mon May 22 2017 Remi Collet <remi@remirepo.net> - 0.9.8-1
- version 0.9.8

* Wed Apr  5 2017 Remi Collet <remi@fedoraproject.org> - 0.9.7-1
- version 0.9.7

* Tue Feb 21 2017 Remi Collet <remi@fedoraproject.org> - 0.9.6-1
- version 0.9.6

* Sun Nov 27 2016 Remi Collet <remi@fedoraproject.org> - 0.9.5-1
- version 0.9.5

* Fri Oct 14 2016 Remi Collet <remi@fedoraproject.org> - 0.9.4-2.20161014git23856e1
- new snapshot to fix PHP 7.1 compatibility of generated code

* Mon Oct 10 2016 Remi Collet <remi@fedoraproject.org> - 0.9.4-1.20160929git22f6632
- new snapshot to fix PHP 7.1 compatibility of generated code

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 0.9.3-2.20160728gite716dbe
- rebuild for PHP 7.1 new API version

* Sat Jul 30 2016 Remi Collet <remi@fedoraproject.org> - 0.9.0-1.20160728gite716dbe
- Initial package

